@@ -2,7 +2,8 @@ package Test::ParallelSubtest;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
+$VERSION = eval $VERSION;
 
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
@@ -14,7 +15,6 @@ our $_i_am_a_child = 0;
 our $MaxParallel = 4;
 
 use Carp;
-use POSIX ();
 use Sub::Prepend ();
 use TAP::Parser;
 use Test::Builder;
@@ -151,7 +151,10 @@ sub _child {
     );
 
     close $write_pipe;
-    POSIX::_exit(0);
+
+    no warnings 'redefine';
+    *Test::Builder::DESTROY = sub {}; # For T::B fork in subtest bug
+    exit(0);
 }
 
 sub bg_subtest_wait {
